@@ -147,7 +147,7 @@ class Object():
 
         self.__dict__.update(data)
 
-    def update(**kwargs):
+    def update(self, **kwargs):
         """
         Updates the object properties in Arena based on attributes passed in.
 
